@@ -25,13 +25,13 @@ def configure_openai():
 
 
 @click.group(invoke_without_command=True)
-@click.version_option(version="1.0.1")
+@click.version_option(version="1.0.2")
 @click.option('--clear', is_flag=True, help='🌊 Clear the context each round of chat')
 def cli(clear):
     """🥝 A command line application to interact with OpenAI's ChatGPT."""
     configure_openai()
     session_data = []
-    click.echo("💻 Session started. Enter 'exit' to end the session.")
+    click.echo("🥝 Session started. Enter 'exit' to end the session.")
     while True:
         user_input = click.prompt("➡ ")
         session_data.append({"role": "user", "content": user_input})
